|pypi| |actions| |codecov| |downloads|



intecomm-form-validators
------------------------


See also https://github.com/intecomm-trial/intecomm-edc



Installation
------------

... in development

.. |pypi| image:: https://img.shields.io/pypi/v/intecomm-form-validators.svg
    :target: https://pypi.python.org/pypi/intecomm-form-validators

.. |actions| image:: https://github.com/intecomm-trial/intecomm-form-validators/workflows/build/badge.svg?branch=develop
  :target: https://github.com/intecomm-trial/intecomm-form-validators/actions?query=workflow:build

.. |codecov| image:: https://codecov.io/gh/intecomm-trial/intecomm-form-validators/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/intecomm-trial/intecomm-form-validators

.. |downloads| image:: https://pepy.tech/badge/intecomm-form-validators
   :target: https://pepy.tech/project/intecomm-form-validators
